@@ -576,7 +576,7 @@ backlight_get_max (GnomeRRScreen *rr_screen, GError **error)
 
 gboolean
 backlight_set_percentage (GnomeRRScreen *rr_screen,
-                          guint value,
+                          gint *value,
                           GError **error)
 {
         GnomeRROutput *output;
@@ -587,17 +587,23 @@ backlight_set_percentage (GnomeRRScreen *rr_screen,
 
         /* prefer xbacklight */
         output = get_primary_output (rr_screen);
-        if (output != NULL)
-                return gnome_rr_output_set_backlight (output, value, error);
+        if (output != NULL) {
+                if (!gnome_rr_output_set_backlight (output, *value, error))
+                        return ret;
+                *value = gnome_rr_output_get_backlight (output);
+                return TRUE;
+        }
 
         /* fall back to the polkit helper */
         max = backlight_helper_get_value ("get-max-brightness", error);
         if (max < 0)
                 return ret;
-        discrete = PERCENTAGE_TO_ABS (min, max, value);
+        discrete = PERCENTAGE_TO_ABS (min, max, *value);
         ret = backlight_helper_set_value ("set-brightness",
                                           discrete,
                                           error);
+        if (ret)
+                *value = ABS_TO_PERCENTAGE (min, max, discrete);
 
         return ret;
 }
@@ -744,20 +750,18 @@ backlight_set_abs (GnomeRRScreen *rr_screen,
 void
 reset_idletime (void)
 {
-        static gboolean inited = FALSE;
-        static KeyCode keycode1, keycode2;
-        static gboolean first_keycode = FALSE;
+        static KeyCode keycode;
 
-        if (inited == FALSE) {
-                keycode1 = XKeysymToKeycode (GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()), GDK_KEY_Alt_L);
-                keycode2 = XKeysymToKeycode (GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()), GDK_KEY_Alt_R);
+        if (keycode == 0) {
+                keycode = XKeysymToKeycode (GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()), GDK_KEY_WakeUp);
+                if (keycode == 0)
+                        keycode = XKeysymToKeycode (GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()), GDK_KEY_Alt_L);
         }
 
         gdk_error_trap_push ();
-        /* send a left or right alt key; first press, then release */
-        XTestFakeKeyEvent (GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()), first_keycode ? keycode1 : keycode2, True, CurrentTime);
-        XTestFakeKeyEvent (GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()), first_keycode ? keycode1 : keycode2, False, CurrentTime);
-        first_keycode = !first_keycode;
+        /* send a wakeup or left alt key; first press, then release */
+        XTestFakeKeyEvent (GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()), keycode, True, CurrentTime);
+        XTestFakeKeyEvent (GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()), keycode, False, CurrentTime);
         gdk_error_trap_pop_ignored ();
 }
 
