@@ -25,7 +25,7 @@
 #include <packagekit-glib2/packagekit.h>
 #include <libupower-glib/upower.h>
 
-#include "gnome-settings-session.h"
+#include "gnome-settings-bus.h"
 
 #include "gsd-updates-common.h"
 #include "gsd-updates-refresh.h"
@@ -64,7 +64,7 @@ struct GsdUpdatesRefreshPrivate
         guint                    periodic_id;
         UpClient                *client;
         GSettings               *settings;
-        GDBusProxy              *proxy_session;
+        GsdSessionManager       *proxy_session;
         PkControl               *control;
 };
 
@@ -393,8 +393,9 @@ periodic_timeout_cb (gpointer user_data)
 }
 
 static void
-gsd_updates_refresh_client_changed_cb (UpClient *client,
-                                       GsdUpdatesRefresh *refresh)
+gsd_updates_refresh_client_on_battery_cb (UpClient *client,
+					  GParamSpec *pspec,
+					  GsdUpdatesRefresh *refresh)
 {
         gboolean on_battery;
 
@@ -497,8 +498,8 @@ gsd_updates_refresh_init (GsdUpdatesRefresh *refresh)
 
         /* use a UpClient */
         refresh->priv->client = up_client_new ();
-        g_signal_connect (refresh->priv->client, "changed",
-                          G_CALLBACK (gsd_updates_refresh_client_changed_cb), refresh);
+        g_signal_connect (refresh->priv->client, "notify::on-battery",
+                          G_CALLBACK (gsd_updates_refresh_client_on_battery_cb), refresh);
 
         /* get the battery state */
         refresh->priv->on_battery = up_client_get_on_battery (refresh->priv->client);
@@ -506,13 +507,13 @@ gsd_updates_refresh_init (GsdUpdatesRefresh *refresh)
 
         /* use gnome-session for the idle detection */
         refresh->priv->proxy_session =
-                gnome_settings_session_get_session_proxy ();
+                gnome_settings_bus_get_session_proxy ();
         if (refresh->priv->proxy_session != NULL) {
-                g_signal_connect (refresh->priv->proxy_session,
+                g_signal_connect (G_DBUS_PROXY (refresh->priv->proxy_session),
                                   "g-signal",
                                   G_CALLBACK (session_presence_signal_cb),
                                   refresh);
-                status = g_dbus_proxy_get_cached_property (refresh->priv->proxy_session,
+                status = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (refresh->priv->proxy_session),
                                                            "status");
                 if (status) {
                         g_variant_get (status, "u", &status_code);
@@ -551,6 +552,7 @@ gsd_updates_refresh_finalize (GObject *object)
                 g_source_remove (refresh->priv->periodic_id);
 
         g_signal_handlers_disconnect_by_data (refresh->priv->client, refresh);
+        g_signal_handlers_disconnect_by_data (refresh->priv->proxy_session, refresh);
 
         g_object_unref (refresh->priv->control);
         g_object_unref (refresh->priv->settings);
